@@ -1,6 +1,6 @@
 import logging
 import os
-import urllib
+import urllib2
 import shutil
 
 from .vcs import Git, Bzr
@@ -156,9 +156,9 @@ class Charm(object):
         if update and os.path.exists(cache_dir):
             shutil.rmtree(cache_dir)
 
+        store_url = "%s/charm/%s" % (STORE_URL, qualified_url[3:])
         with temp_file() as fh:
-            ufh = urllib.urlopen("%s/charm/%s" % (
-                STORE_URL, qualified_url[3:]))
+            ufh = urllib2.urlopen(store_url)
             shutil.copyfileobj(ufh, fh)
             fh.flush()
             extract_zip(fh.name, self.path)
