@@ -19,7 +19,7 @@ class Bzr(BaseBzr):
             ["bzr", "init", self.path],
             "Could not initialize repo at  %(path)s")
         try:
-            subprocess.check_call(["bzr", "whoami"])
+            subprocess.check_output(["bzr", "whoami"])
         except subprocess.CalledProcessError:
             subprocess.check_call([
                 "bzr", "whoami", "TestRunner <test@example.com>"])
